==> hydrate-vue-todo-1.8.0.tgz: package/README.md <==
# hydrate-vue-todo

> Almost instant Vue.js app init from the HTML stored from previous run

[![NPM][hydrate-vue-todo-icon] ][hydrate-vue-todo-url]

[![Build status][hydrate-vue-todo-ci-image] ][hydrate-vue-todo-ci-url]
[![semantic-release][semantic-image] ][semantic-url]

Demo [glebbahmutov.com/hydrate-vue-todo/](http://glebbahmutov.com/hydrate-vue-todo/)

The demo shows an application loading, but while it is loading, a "fake" DOM snapshot
is inserted. This fake snapshot is saved from the "app" element every time the Todo list
has changes. If the 'vue.js' library is taking long time to load from a CDN, this
"fake" DOM becomes much better than a blank page. Of course, the user cannot interact
with the "fake" - thus I show a blue overlay to stop the user.

### Small print

Author: Gleb Bahmutov &copy; 2015

* [@bahmutov](https://twitter.com/bahmutov)
* [glebbahmutov.com](http://glebbahmutov.com)
* [blog](http://glebbahmutov.com/blog/)

License: MIT - do anything with the code, but don't blame me if it does not work.

Spread the word: tweet, star on github, etc.

Support: if you find any problems with this module, email / tweet /
[open issue](https://github.com/bahmutov/hydrate-vue-todo/issues) on Github

## MIT License

Copyright (c) 2015 Gleb Bahmutov

Permission is hereby granted, free of charge, to any person
obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without
restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following
conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

[hydrate-vue-todo-icon]: https://nodei.co/npm/hydrate-vue-todo.png?downloads=true
[hydrate-vue-todo-url]: https://npmjs.org/package/hydrate-vue-todo
[hydrate-vue-todo-ci-image]: https://travis-ci.org/bahmutov/hydrate-vue-todo.png?branch=master
[hydrate-vue-todo-ci-url]: https://travis-ci.org/bahmutov/hydrate-vue-todo
[semantic-image]: https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg
[semantic-url]: https://github.com/semantic-release/semantic-release

==> hydrate-vue-todo-1.13.0.tgz: package/README.md <==
# hydrate-vue-todo

> Almost instant Vue.js app init from the HTML stored from previous run

[![NPM][hydrate-vue-todo-icon] ][hydrate-vue-todo-url]

[![Build status][hydrate-vue-todo-ci-image] ][hydrate-vue-todo-ci-url]
[![semantic-release][semantic-image] ][semantic-url]

Demo [glebbahmutov.com/hydrate-vue-todo/](https://glebbahmutov.com/hydrate-vue-todo/),
[glebbahmutov.com/hydrate-vue-todo/bare.html](https://glebbahmutov.com/hydrate-vue-todo/bare.html)

The demo shows an application loading, but while it is loading, a "fake" DOM snapshot
is inserted. This fake snapshot is saved from the "app" element every time the Todo list
has changes. If the 'vue.js' library is taking long time to load from a CDN, this
"fake" DOM becomes much better than a blank page. Of course, the user cannot interact
with the "fake" - thus I show a blue overlay to stop the user.

### Small print

Author: Gleb Bahmutov &copy; 2015

* [@bahmutov](https://twitter.com/bahmutov)
* [glebbahmutov.com](http://glebbahmutov.com)
* [blog](http://glebbahmutov.com/blog/)

License: MIT - do anything with the code, but don't blame me if it does not work.

Spread the word: tweet, star on github, etc.

Support: if you find any problems with this module, email / tweet /
[open issue](https://github.com/bahmutov/hydrate-vue-todo/issues) on Github

## MIT License

Copyright (c) 2015 Gleb Bahmutov

Permission is hereby granted, free of charge, to any person
obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without
restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following
conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

[hydrate-vue-todo-icon]: https://nodei.co/npm/hydrate-vue-todo.png?downloads=true
[hydrate-vue-todo-url]: https://npmjs.org/package/hydrate-vue-todo
[hydrate-vue-todo-ci-image]: https://travis-ci.org/bahmutov/hydrate-vue-todo.png?branch=master
[hydrate-vue-todo-ci-url]: https://travis-ci.org/bahmutov/hydrate-vue-todo
[semantic-image]: https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg
[semantic-url]: https://github.com/semantic-release/semantic-release
